"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.clearLazyHydrateRegistries = clearLazyHydrateRegistries;
exports.LazyStyleElements = LazyStyleElements;
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _useIntersectionObserver = _interopRequireDefault(require("./hooks/useIntersectionObserver"));

var _styles = require("@material-ui/core/styles");

var _jss = require("jss");

var registries = [];
var generateClassName = (0, _styles.createGenerateClassName)();

function clearLazyHydrateRegistries() {
  registries = [];
}
/*
  This component renders the server side rendered stylesheets for the
  lazy hydrated components. Once they become hydrated, these stylesheets
  will be removed.
*/


function LazyStyleElements() {
  return _react["default"].createElement(_react["default"].Fragment, null, registries.map(function (registry, index) {
    var id = "jss-lazy-".concat(index);
    return _react["default"].createElement("style", {
      key: id,
      id: id,
      dangerouslySetInnerHTML: {
        __html: registry.toString()
      }
    });
  }));
}

function LazyStylesProvider(_ref) {
  var children = _ref.children;
  var registry = new _jss.SheetsRegistry();
  registries.push(registry);
  return _react["default"].createElement(_styles.StylesProvider, {
    sheetsManager: new Map(),
    serverGenerateClassName: generateClassName,
    sheetsRegistry: registry
  }, children);
}

var isBrowser = function isBrowser() {
  if (process.env.NODE_ENV === 'test') {
    return process.env.IS_BROWSER === 'true';
  }

  return typeof window !== 'undefined' && typeof window.document !== 'undefined' && typeof window.document.createElement !== 'undefined';
};

function LazyHydrateInstance(_ref2) {
  var className = _ref2.className,
      ssrOnly = _ref2.ssrOnly,
      children = _ref2.children,
      on = _ref2.on,
      index = _ref2.index,
      props = (0, _objectWithoutProperties2["default"])(_ref2, ["className", "ssrOnly", "children", "on", "index"]);

  function isHydrated() {
    if (isBrowser()) {
      if (ssrOnly) return false;
      return props.hydrated;
    } else {
      return true;
    }
  }

  var childRef = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(isHydrated()),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      hydrated = _useState2[0],
      setHydrated = _useState2[1];

  function hydrate() {
    setHydrated(true); // Remove the server side generated stylesheet

    var stylesheet = window.document.getElementById("jss-lazy-".concat(index));

    if (stylesheet) {
      stylesheet.remove();
    }
  }

  (0, _react.useEffect)(function () {
    setHydrated(isHydrated());
  }, [props.hydrated, ssrOnly]);

  if (on === 'visible') {
    (0, _useIntersectionObserver["default"])( // As root node does not have any box model, it cannot intersect.
    function () {
      return childRef.current.children[0];
    }, function (visible, disconnect) {
      if (visible) {
        hydrate();
        disconnect();
      }
    }, [], // Fallback to eager hydration
    function () {
      hydrate();
    });
  }

  (0, _react.useEffect)(function () {
    if (hydrated) return;

    if (on === 'click') {
      childRef.current.addEventListener('click', hydrate, {
        once: true,
        capture: true,
        passive: true
      });
    }

    return function () {
      if (on === 'click') {
        childRef.current.removeEventListener('click', hydrate);
      }
    };
  }, [hydrated, on]);

  if (hydrated) {
    return _react["default"].createElement("div", {
      ref: childRef,
      style: {
        display: 'contents'
      },
      className: className
    }, children);
  } else {
    return _react["default"].createElement("div", {
      ref: childRef,
      className: className,
      style: {
        display: 'contents'
      },
      suppressHydrationWarning: true,
      dangerouslySetInnerHTML: {
        __html: ''
      }
    });
  }
}
/**
 * LazyHydrate
 *
 * Example:
 *
 *  <LazyHydrate on="visible">
 *    <div>some expensive component</div>
 *  </LazyHydrate>
 *
 */


function LazyHydrate(_ref3) {
  var children = _ref3.children,
      props = (0, _objectWithoutProperties2["default"])(_ref3, ["children"]);
  return _react["default"].createElement(LazyHydrateInstance, (0, _extends2["default"])({}, props, {
    index: registries.length
  }), _react["default"].createElement(LazyStylesProvider, null, children));
}

LazyHydrate.propTypes = {
  // Control the hydration of the component externally with this prop
  hydrated: _propTypes["default"].bool,
  // Force component to never hydrate
  ssrOnly: _propTypes["default"].bool,
  // Event to trigger hydration
  on: _propTypes["default"].oneOf(['visible', 'click'])
};
var _default = LazyHydrate;
exports["default"] = _default;
//# sourceMappingURL=LazyHydrate.js.map