"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = FacetGroup;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireWildcard(require("react"));

var _SearchResultsContext = _interopRequireDefault(require("./SearchResultsContext"));

var _styles = require("@material-ui/core/styles");

var _ExpandableSection = _interopRequireDefault(require("../ExpandableSection"));

var _CheckboxFilterGroup = _interopRequireDefault(require("./CheckboxFilterGroup"));

var _ButtonFilterGroup = _interopRequireDefault(require("./ButtonFilterGroup"));

var styles = function styles(theme) {
  return {
    /**
     * Styles applied to the group's title element.
     */
    groupTitle: (0, _defineProperty2["default"])({}, theme.breakpoints.up('sm'), {
      fontWeight: 'bold'
    })
  };
};

var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFFacetGroup'
});
/**
 * A grouping of facets used for filtering products.
 */

function FacetGroup(props) {
  var group = props.group,
      submitOnChange = props.submitOnChange,
      defaultExpanded = props.defaultExpanded;
  var classes = useStyles(props.classes);

  var _useContext = (0, _react.useContext)(_SearchResultsContext["default"]),
      filters = _useContext.pageData.filters;

  return (0, _react.useMemo)(function () {
    if (!filters) return null;
    var selection = [];
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = group.options[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var option = _step.value;

        if (filters.indexOf(option.code) !== -1) {
          selection.push(option);
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator["return"] != null) {
          _iterator["return"]();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    var Controls;

    if (group.ui === 'buttons') {
      Controls = _ButtonFilterGroup["default"];
    } else {
      Controls = _CheckboxFilterGroup["default"];
    }

    var caption = null;

    if (selection.length === 1) {
      caption = selection[0].name;
    } else if (selection.length > 0) {
      caption = "".concat(selection.length, " selected");
    }

    return _react["default"].createElement(_ExpandableSection["default"], {
      title: group.name,
      caption: caption,
      defaultExpanded: defaultExpanded,
      classes: {
        title: classes.groupTitle
      }
    }, _react["default"].createElement(Controls, {
      group: group,
      submitOnChange: submitOnChange
    }));
  }, [].concat((0, _toConsumableArray2["default"])(Object.values(props)), [filters]));
}

FacetGroup.propTypes = {
  /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */
  classes: _propTypes["default"].object,
  // TODO - make this a shape

  /**
   * Contains data for the facet group to be rendered.
   */
  group: _propTypes["default"].object,

  /**
   * Set to `true` to refresh the results when the user toggles a filter.
   */
  submitOnChange: _propTypes["default"].bool,

  /**
   * If `true`, the group is expanded by default.
   */
  defaultExpanded: _propTypes["default"].bool
};
//# sourceMappingURL=FacetGroup.js.map