"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = lazyLoadImages;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

/**
 * Observes the visibility of all `img` elements inside the specified element
 * that match the specified selector. When an image becomes visible, the `data-src`
 * attribute is copied to `src`.
 *
 * See https://developers.google.com/web/fundamentals/performance/lazy-loading-guidance/images-and-video/
 * @param {DOMElement} element The img element to lazy load
 * @param {Object} options
 * @param {Object} options.lazySrcAttribute The attribute containing the image URL. Defaults to `data-src`.
 */
function lazyLoadImages(element) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref$lazySrcAttribute = _ref.lazySrcAttribute,
      lazySrcAttribute = _ref$lazySrcAttribute === void 0 ? 'data-src' : _ref$lazySrcAttribute;

  if (!element) return;
  var lazyImages = (0, _toConsumableArray2["default"])(element.querySelectorAll("img[".concat(lazySrcAttribute, "]")));
  if (!lazyImages.length) return;
  var lazyImageObserver;

  var load = function load(img) {
    var src = img.getAttribute(lazySrcAttribute);

    var onload = function onload() {
      img.removeAttribute(lazySrcAttribute);
      img.removeEventListener('load', onload);
    };

    img.addEventListener('load', onload);
    img.setAttribute('src', src);

    if (lazyImageObserver) {
      lazyImageObserver.disconnect(img);
    }
  };

  var observerHandler = function observerHandler(entries) {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = entries[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var entry = _step.value;

        if (entry.isIntersecting) {
          load(entry.target);
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator["return"] != null) {
          _iterator["return"]();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  };

  try {
    lazyImageObserver = new window.IntersectionObserver(observerHandler);
    var _iteratorNormalCompletion2 = true;
    var _didIteratorError2 = false;
    var _iteratorError2 = undefined;

    try {
      for (var _iterator2 = lazyImages[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
        var img = _step2.value;
        lazyImageObserver.observe(img);
      }
    } catch (err) {
      _didIteratorError2 = true;
      _iteratorError2 = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion2 && _iterator2["return"] != null) {
          _iterator2["return"]();
        }
      } finally {
        if (_didIteratorError2) {
          throw _iteratorError2;
        }
      }
    }

    return lazyImageObserver;
  } catch (e) {
    // eagerly load images when we don't have the observer
    var _iteratorNormalCompletion3 = true;
    var _didIteratorError3 = false;
    var _iteratorError3 = undefined;

    try {
      for (var _iterator3 = lazyImages[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
        var _img = _step3.value;
        load(_img);
      }
    } catch (err) {
      _didIteratorError3 = true;
      _iteratorError3 = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion3 && _iterator3["return"] != null) {
          _iterator3["return"]();
        }
      } finally {
        if (_didIteratorError3) {
          throw _iteratorError3;
        }
      }
    }
  }
}
//# sourceMappingURL=lazyLoadImages.js.map